class ItemsController < ApplicationController
  # GET /items
  # GET /items.xml
  def index
    @items = Item.paginate :page => params[:page], :order => "id", :per_page => 25

    respond_to do |format|
      format.html # index.html.erb
      format.xml  { render :xml => @items }
    end
  end

  # GET /items/1
  # GET /items/1.xml
  def show
    @item = Item.find(params[:id])

    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @item }
    end
  end

  def mass_update
    if (params[:commit] && params[:commit] != '')
      items = Array.new
      case params[:commit]
        when "Move Selected"
	  if params[:move_to] && params[:move_to] != ''
	    if params[:move_to] == -1
	      params[:move_to] = nil
	    end
            params.each do |p,v|
              if p.match(/^item_(\d+)$/)
	        i = Item.find($1)
		i.box_id = params[:move_to]
		i.save
	      end
            end
	  else
	    flash[:notice] = "Can't move without a destination."
	  end
        when "Delete Selected"
	  count = 0
	  params.each do |p,v|
	    if p.match(/^item_(\d+)$/)
	      i = Item.find($1)
	      i.destroy
	      count += 1
	    end
	  end
	  flash[:notice] = "Deleted #{count} item#{count == 1 ? "" : "s"}."
        else
	  flash[:notice] = "Unknown action (#{params[:commit]})"
      end
    else
      flash[:notice] = "No commit, nothing to do."
    end
    respond_to do |format|
      format.html { redirect_to(items_url) }
      format.xml  { head :ok }
    end
  end

  def by_box
    @items = Box.find(params[:box]).items.paginate :page => params[:page], :order => "id", :per_page => 25

    respond_to do |format|
      format.html { render :action => "index" }
      format.xml  { render :xml => @items }
    end
  end

  def by_desc
    @items = Item.by_desc(params[:desc]).paginate :page => params[:page], :order => "id", :per_page => 25

    respond_to do |format|
      format.html { render :action => "index" }
      format.xml  { render :xml => @items }
    end
  end

  def by_notes
    @items = Item.by_notes(params[:notes]).paginate :page => params[:page], :order => "id", :per_page => 25

    respond_to do |format|
      format.html { render :action => "index" }
      format.xml  { render :xml => @items }
    end
  end

  def by_text
    @items = Item.by_text(params[:text]).paginate :page => params[:page], :order => "id", :per_page => 25

    respond_to do |format|
      format.html { render :action => "index" }
      format.xml  { render :xml => @items }
    end
  end

  # GET /items/new
  # GET /items/new.xml
  def new
    @item = Item.new

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @item }
    end
  end

  # GET /items/1/edit
  def edit
    @item = Item.find(params[:id])
  end

  # POST /items
  # POST /items.xml
  def create
    @item = Item.new(params[:item])

    respond_to do |format|
      if @item.save
        flash[:notice] = 'Item was successfully created.'
        format.html { redirect_to(@item) }
        format.xml  { render :xml => @item, :status => :created, :location => @item }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @item.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /items/1
  # PUT /items/1.xml
  def update
    @item = Item.find(params[:id])

    respond_to do |format|
      if @item.update_attributes(params[:item])
        flash[:notice] = 'Item was successfully updated.'
        format.html { redirect_to(@item) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @item.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /items/1
  # DELETE /items/1.xml
  def destroy
    @item = Item.find(params[:id])
    @item.destroy

    respond_to do |format|
      format.html { redirect_to(items_url) }
      format.xml  { head :ok }
    end
  end
end
